## This file contains the analysis performed by Fernando E. Miguez
## for a publication titled

## Meta-Analysis of the Effects of Management Practices on
## Miscanthus x giganteus growth and biomass production.

## As long as you acknowledge the use of this you can do whatever
## you want with it.

## NOTE: The packages needed are nlme, lattice and grid.
## The recommended packages were also installed for this
## session

library(nlme)
library(lattice)
library(grid)

## Set the working directory accordingly
misc <- read.csv("MiscanthusDatabase.csv",header=T)
names(misc)

## boxplots

par(mfrow=c(1,2))
boxplot(misc$FallYield,main="Fall Yield",ylim=c(0,40))
boxplot(misc$SpringYield,main="Spring Yield",ylim=c(0,40))

## Scatterplots

par(mfrow=c(2,1),mar=c(0,4.5,0.5,0.5),omi=c(1,0,0,0))
plot(SpringYield ~ Season, data=misc, xaxt="n",
 ylab=expression(paste("dry biomass ","(Mg ",ha^-1,")")),ylim=c(0,40))
 legend(9,37,legend="Winter yield",bty="n")
plot(FallYield ~ Season, data=misc, xlab="Season",
 ylab=expression(paste("dry biomass ","(Mg ",ha^-1,")")),ylim=c(0,40))
 legend(9.5,37,legend="Fall yield",bty="n")
 mtext("Season",side=1,line=2,at=7)

## Non-linear model

misc.cc <- misc[misc$Season < 8 ,]
misc.c <- misc.cc[-422,]

attach(misc.c)
misc.co <- misc.c[order(EU),]
misc.co$EU <- ordered(misc.co$EU)
detach(misc.c)

attach(misc.co)

 misc2 <- data.frame(SpringYield,Season,EU,Country,Location,PlantDensity,NRATE)
##> misc2 <- data.frame(SpringYield,Season,EU,Country,Location)
 detach(misc.co)
 misc2.nmd <- na.omit(misc2)


 miscG <- groupedData( SpringYield ~ Season | EU, data=misc2.nmd, labels=list(y="dry biomass"),units=list(y="(Mg/ha)"))

 plot(miscG,grid=F,layout=c(10,7),col="black",xlab=list("Season",cex=1.5),ylab=list(expression(paste("dry biomass  ","(Mg ",ha^-1,")")),cex=1.5),
 as.table=T,aspect=1)

## Other possible plots (not included or necessary)

plot(miscG,grid=F,par.strip.text=list(cex=0.5),col="black",
 ylab=expression(paste("dry biomass  ","(Mg ",ha^-1,")")),as.table=T)

 plot(miscG,grid=F,layout=c(17,4),col="black",lab.cex=1.2,
      xlab=list("Season",cex=1.5),
 ylab=list(expression(paste("dry biomass  ","(Mg ",ha^-1,")")),
   cex=1.5),as.table=T)

## Fitting an individual non-linear model to each EU

 fitnls.list <- nlsList(SpringYield ~ SSlogis(Season,Asym,xmid,scal),
                        data=miscG)
 plot(intervals(fitnls.list))

## fitting the simple model

 fit0.nlme <- nlme(fitnls.list)

## This general model is too complex and it doesn't converge
## A more simple model is needed

 fit.nlme <- nlme(fitnls.list,random=pdDiag(Asym+xmid+scal~1))

 fit1.nlme <- nlme(fitnls.list,random=list(Asym+xmid~1))

## The residuals look good

plot(fit1.nlme , id=0.05)

plot(augPred(fit1.nlme, level=0:1),layout=c(10,7),aspect=1,
     xlab=list("Season",cex=1.5),
ylab=list(expression(paste("dry biomass  ","(Mg ",ha^-1,")")),cex=1.5),
     lty=c(1,2),col="black",as.table=T,
     key=list(text=list(c("fixed","EU")),lty=c(1,2),lines=T))

## Effect of planting density

 miscFix <- fixef(fit1.nlme)
 fit2.nlme <- update(fit1.nlme, fixed = Asym + xmid + scal ~ PlantDensity,
  start = c(miscFix[1], 0, miscFix[2], 0, miscFix[3], 0))
 anova(fit2.nlme)

## Planting density has an effect on xmid mainly

 miscFix <- fixef(fit1.nlme)
 fit3.nlme <- update(fit1.nlme, fixed = Asym + xmid + scal ~ NRATE,
  start = c(miscFix[1], 0, miscFix[2], 0, miscFix[3], 0))
 anova(fit3.nlme)

## Nitrogen rate has an effect on Asym mainly

 miscFix <- fixef(fit1.nlme)
 fit4.nlme <- update(fit1.nlme,
                     fixed = Asym + xmid + scal ~ NRATE + PlantDensity,
  start = c(miscFix[1], 0,0, miscFix[2], 0,0, miscFix[3], 0,0))

## So far the model seems to work well. However, I couldn't fit
## a model that considers the possible interaction between
## plant density and Nrate

fit5.nlme <- update(fit4.nlme,random=list(Country=pdDiag(Asym+xmid~1),
              location=pdDiag(Asym+xmid~1),EU=pdDiag(Asym+xmid~1)),
                    groups=~Country/Location/EU)

## The previous code tries to account for the hierarchical nature of the 
## data. EU are nested within location and countries. First, I'm
## trying to fit a relatively simple model with diagonal covariance 
## matrices because of computational problems

## simpler

fit6.nlme <- update(fit5.nlme,random=list(Country=Asym~1,
location=Asym~1,EU=pdDiag(Asym+xmid~1)),groups=~Country/Location/EU)

anova(fit5.nlme,fit6.nlme)

pairs(ranef(fit5.nlme,level=1))
pairs(ranef(fit5.nlme,level=2))
pairs(ranef(fit5.nlme,level=3))

## No visual evidence of correlation among the random effects

## Even simpler

fit7.nlme <- update(fit5.nlme,random=list(Country=Asym~1,
location=Asym~1,EU=Asym~1),groups=~Country/Location/EU)
anova(fit6.nlme,fit7.nlme)

## A simpler model is too simple model 6 is retained

anova(fit6.nlme)
## This ANOVA table is Table 1.4 in the thesis
save.image("miscRes.RData")
## Calculating predictions

 new.misc <- list(Season=seq(1,7),PlantDensity=seq(1,4),NRATE=c(0,25,50,100))
 new.misc <- expand.grid(new.misc)

 pp <- predict(fit6.nlme,newdata=new.misc,level=0)
 preds <- cbind(new.misc,pp)
 names(preds)

## Effect of nitrogen effect

 xyplot(pp ~ Season | factor(PlantDensity),groups=NRATE,data=preds,type="b"
  ,lwd=2,lty=c(1,2,3,4),col="black",as.table=T,
ylab=expression(paste("dry biomass  ","(Mg ",ha^-1,")")),key=list(text=list(c("0","25","50","100")),lty=c(1,2,3,4)
,lines=T,lwd=2,x=0.75,y=0.25) )

## Effect of planting density


 xyplot(pp ~ Season | factor(NRATE),groups=PlantDensity,data=preds,type="b"
  ,lwd=2,lty=c(1,2,3,4),col="black",as.table=T,
ylab=expression(paste("dry biomass  ","(Mg ",ha^-1,")")),key=list(text=list(c("1","2","3","4")),lty=c(1,2,3,4)
,lines=T,lwd=2,x=0.75,y=0.25) )

## Simpler plots ##################################

## Calculating predictions

 new.misc <- list(Season=seq(1,7),PlantDensity=c(1,4),NRATE=c(0,100))
 new.misc <- expand.grid(new.misc)

 pp <- predict(fit6.nlme,newdata=new.misc,level=0)
 preds <- cbind(new.misc,pp)
 names(preds)

## Effect of nitrogen effect

plot1 <-  xyplot(pp ~ Season | factor(PlantDensity),groups=NRATE,data=preds,type="b"
  ,lwd=2,lty=c(1,2),col="black",as.table=T,xlab=NULL,
ylab=expression(paste("dry biomass  ","(Mg ",ha^-1,")")),key=list(text=list(c("0","100")),lty=c(1,2)
,lines=T,lwd=2,x=0.75,y=0.25))

plot2 <- xyplot(pp ~ Season | factor(NRATE),groups=PlantDensity,data=preds,type="b"
  ,lwd=2,lty=c(1,2),col="black",as.table=T,
ylab=expression(paste("dry biomass  ","(Mg ",ha^-1,")")),key=list(text=list(c("1","4")),lty=c(1,2)
,lines=T,lwd=2,x=0.75,y=0.25) )

pdf("PlantNrate.pdf")
print(plot1 , position=c(0,0.45,1,1),more=TRUE)
grid.text("a)",x=0.07,y=0.93,gp=gpar(fontsize=20))
print(plot2, position=c(0,0,1,0.55))
grid.text("b)",x=0.07,y=0.5,gp=gpar(fontsize=20))
dev.off()




## Confidence intervals for the fixed components

intervals(fit6.nlme , which="fixed")

## Test of Gompertz vs. logistic

gfit.lis <- nlsList(SpringYield ~ SSgompertz(Season,Asym,b2,b3),data=miscG)
plot(intervals(gfit.lis))

gfit0.nlme <- nlme(gfit.lis)
gfit1.nlme <- nlme(gfit.lis, random = pdDiag(Asym + b2 + b3 ~ 1))
gfit2.nlme <- nlme(gfit.lis, random = Asym~ 1)

anova(gfit1.nlme,gfit2.nlme)
## The simpler model is retained

plot(augPred(gfit2.nlme, level=0:1),layout=c(10,7),aspect=1,
     xlab=list("Season",cex=1.5),
ylab=list(expression(paste("dry biomass  ","(Mg ",ha^-1,")")),cex=1.5),
     lty=c(1,2),col="black",as.table=T,
     key=list(text=list(c("fixed","EU")),lty=c(1,2),lines=T))

## Effect of planting density and NRATE

 gmiscFix <- fixef(gfit2.nlme)
 gfit3.nlme <- update(gfit2.nlme, fixed = Asym + b2 + b3
                      ~ PlantDensity + NRATE,
  start = c(gmiscFix[1], 0,0, gmiscFix[2], 0,0, gmiscFix[3], 0,0))
 anova(gfit3.nlme)

gfit4.nlme <- update(gfit3.nlme,random=list(Country=Asym~1,
location=Asym~1,EU=Asym~1),groups=~Country/Location/EU)
anova(gfit3.nlme,gfit4.nlme)

## Model gfit3.nlme was retained and logis is better than gompertz
anova(fit6.nlme,gfit3.nlme)

## Calculating predictions

 new.misc <- list(Season=seq(1,7),PlantDensity=seq(1,4),NRATE=c(0,25,50,100))
 new.misc <- expand.grid(new.misc)

 pp <- predict(gfit4.nlme,newdata=new.misc,level=0)
 preds <- cbind(new.misc,pp)
 names(preds)

## Effect of nitrogen effect

 xyplot(pp ~ Season | factor(PlantDensity),groups=NRATE,data=preds,type="b"
  ,lwd=2,lty=c(1,2,3,4),col="black",as.table=T,
ylab=expression(paste("dry biomass  ","(Mg ",ha^-1,")")),key=list(text=list(c("0","25","50","100")),lty=c(1,2,3,4)
,lines=T,lwd=2,x=0.75,y=0.25) )


## Analysis for the within growing season

 comb <- read.csv("Comb(w-season).csv",header=T)

combG <- groupedData(dry.biomass ~ ThermalT | Location, data=comb, labels=list(y="dry biomass"),units=list(y="(Mg/ha)"))
plot(combG)

fit.lis <- nlsList(dry.biomass ~ SSlogis(ThermalT,Asym,xmid,scal),data=combG)
fit.nlme <- nlme(fit.lis)
 fit.nlme

fit2.nlme <- update(fit.nlme,random=pdBlocked(list(Asym~1,xmid+scal~1)))
fit3.nlme <- update(fit2.nlme,random=pdDiag(xmid+scal~1))
fit4.nlme <- update(fit3.nlme,random=xmid~1)

plot(augPred(fit4.nlme,level=0:1),col="black",lty=c(1,2),lwd=c(2,1),
 ylab=expression(paste("dry biomass ","(Mg ",ha^-1,")")),
 xlab=expression(paste("Thermal time (",degree,"C day)")),scales=list(cex=0.7),as.table=T,
 key=list(text=list(c("Fixed","Location")),lty=c(1,2),lines=T,cex=1.2,col="black"))




